Nodes — MARV Robotics 19.04.0 documentation

# Nodes

## Bag metadata

`marv_robotics.bag.` `bagmeta`()

  Extract meta information from bag file.

  In case of multiple connections for one topic, they are assumed to be all of the same message type and either all be latching or none.

  A topic’s message type and latching mode, and a message type’s md5sum are assumed not to change across split bags.

## ROS bag messages

`marv_robotics.bag.` `raw_messages`()

  Stream messages from a set of bag files.

`marv_robotics.bag.` `get_message_type`(stream)

  ROS message type from definition stored for stream.

## Images

`marv_robotics.cam.` `images`()

  Extract max_frames equidistantly spread images from each sensor_msgs/Image stream.

  Parameters: | stream – sensor_msgs/Image stream image_width (int) – Scale to image_width, keeping aspect ratio. max_frames (int) – Maximum number of frames to extract.

## Video

`marv_robotics.cam.` `ffmpeg`()

  Create video for each sensor_msgs/Image topic with ffmpeg

## Fulltext

`marv_robotics.fulltext.` `fulltext`()

  Extract all text from bag file and store for fulltext search

## GNSS

`marv_robotics.gnss.` `positions`()

`marv_robotics.gnss.` `imus`()

`marv_robotics.gnss.` `navsatorients`()

`marv_robotics.gnss.` `orientations`()

`marv_robotics.gnss.` `gnss_plots`()

## Trajectory

`marv_robotics.trajectory.` `navsatfix`()

`marv_robotics.trajectory.` `trajectory`()

## Widget nodes

Widgets are used by sections or are rendered in the special summary sections when configured in the detail_summary_widgets config key.

`marv_robotics.detail.` `bagmeta_table`()

  Table widget listing metadata for each bag of dataset.

  Useful for detail_summary_widgets.

`marv_robotics.detail.` `summary_keyval`()

  Keyval widget summarizing bag metadata.

  Useful for detail_summary_widgets.

`marv_robotics.detail.` `galleries`()

  Galleries for all images streams.

  Used by marv_robotics.detail.images_section.

## Section nodes

`marv_robotics.detail.` `images_section`()

  Section with galleries of images for each images stream.

`marv_robotics.detail.` `connections_section`()

  Section displaying information about ROS connections.

`marv_robotics.detail.` `trajectory_section`()

  Section displaying trajectory on a map.

  Parameters: | tile_server_protocol (str) – Set to `https:` if you host marv behind http and prefer the tile requests to be secured.

`marv_robotics.detail.` `video_section`()

  Section displaying one video player per image stream.

`marv_robotics.detail.` `gnss_section`()

  Section displaying GNSS plots.